# œ.js
## A JavaScript library similar to jQuery, that manipulates the DOM. By the way, this is my first JS library.
[![github muffins](https://img.shields.io/badge/Muffins-1-brightgreen.svg?style=flat)](https://github.com/RailRunner16/oe.js/blob/master)
___
[![GitHub version](https://badge.fury.io/gh/RailRunner16%2Foe.js.svg)](https://badge.fury.io/gh/RailRunner16%2Foe.js)
[![npm version](https://badge.fury.io/js/oe-like-jquery.svg)](https://badge.fury.io/js/oe-like-jquery)
[![npm](https://img.shields.io/npm/l/express.svg)](https://github.com/RailRunner16/oe.js/blob/add-license-1/LICENSE)
[![GitHub language count](https://img.shields.io/github/languages/count/badges/shields.svg)](https://github.com/RailRunner16/oe.js/blob/master)
[![GitHub top language](https://img.shields.io/github/languages/top/badges/shields.svg)](https://github.com/RailRunner16/oe.js/blob/master/œ.js)
___
### CDN for Œ.js:
##### For development:
- Changes to the library are updated within minutes.
- Excessive traffic will be throttled and blacklisted.
- If excessive traffic continues, a prominent error message will be displayed on your website to try to get your attention.
- `<script>` tag for non-minified version:
    ```html
    <script async type="text/javascript" src="https://rawgit.com/RailRunner16/oe.js/master/%C5%93.js"></script>
    ```
- `<script>` tag for minified version:
    ```html
    <script async type="text/javascript" src="https://rawgit.com/RailRunner16/oe.js/master/%C5%93.min.js"></script>
    ```
##### For production:
- No traffic limits or throttling.
- Use a specific tag or commit hash in the URL (not a branch). Files are cached permanently based on the URL. Query strings are ignored.
- The catch: no uptime or support guarantees, since I am serving files from RawGit.
- `<script>` tag for non-minified version::
    ```html
    <script async type="text/javascript" src="https://cdn.rawgit.com/RailRunner16/oe.js/309a0b7d/%C5%93.js"></script>
    ```
- `<script>` tag for minified version::
    ```html
    <script async type="text/javascript" src="https://cdn.rawgit.com/RailRunner16/oe.js/6d856066/%C5%93.min.js"></script>
    ```
___
### Selecting a DOM element:
`_œ()` is this library's equivalent to jQuery's `$()`. It can select elements by id with the syntax: `_œ('id')`, just dont put the pound symbol in the id.

###### To get the _œ_ character, do <kbd>rightalt + x</kbd> on an extended U.S. keyboard.
___
### Functions:
#### Standard Functions
- `show()`:
  - Displays a hidden DOM element. If the DOM element is visible already, it will do nothing.
  - Syntax:
    ```javascript
    _œ('selector').show();
    ```
- `hide()`:
  - Hides a visible DOM element. If the DOM element is already hidden, it will do nothing.
  - Syntax:
    ```javascript
    _œ('selector').hide();
    ```
- `on(event, callback)`:
  - This function gives the selected element(s) one or more event handlers. It will work on any element.
  - Syntax:
    ```javascript
    _œ('selector').on(event, function(){
      // Perform your operation here
    });
    ```
- `bgcolor(color)`:
  - This function sets the background of the selected element(s). It will not work on non visible components or components that have been hidden. It can process any type of color values that HTML can. (For example: RGB, RGBA, Hex values all work.)
  - Syntax:
    ```javascript
    _œ('selector').bgcolor(color);
    ```
- `val(newval)`:
  - This function sets the value of the selected element to the specified new value. It only works on elements with the `value` attribute.
  - Syntax
    ```javascript
    _œ('selector').val(new_value);
    ```
- `css(attr, value)`:
  - This function will change any CSS property of a given element. All you have to do is specify the property
and the new value.
  - Syntax:
    ```javascript
    _œ('selector').css(property, newvalue);
    ```
- `size(width, height)`:
  - Changes the size of the selected element. Accepts two parameters: width and height.
  - Syntax:
    ```javascript
    _œ('selector').size(width, height);
    ```
- `width(width)`:
  - Changes the width of the selected element.
  - Syntax:
    ```javascript
    _œ('selector').width(width);
    ```
- `height(height)`:
  - Changes the height of the selected element.
  - Syntax:
    ```javascript
    _œ('selector').height(height);
    ```
- `html(content)`:
  - Changes the inner HTML content of the selected element.
  - Syntax:
    ```javascript
    _œ('selector').html(newcontent);
    ```
#### Event Handlers
- `click(callback)`:
  - This event handler is triggered when the specified object is cicked.
  - Syntax:
    ```javascript
    _œ('selector').click(function(){
      // Callback code goes here.
    });
    ```
- `doubleClick(callback)`:
  - This event handler is triggered when the specified object is cicked twice in a row.
  - Syntax:
    ```javascript
    _œ('selector').doubleClick(function(){
      // Callback code goes here.
    });
    ```
- `mouseWheel(callback)`:
  - This event handler is triggered when the mouse wheel is is being or just has been scrolled.
  - Syntax:
    ```javascript
    _œ('selector').mouseWheel(function(){
      // Callback code goes here.
    });
    ```
- `mouseOver(callback)`:
  - This event handler is triggered when the specified object is being hovered over by the user's cursor.
  - Syntax:
    ```javascript
    _œ('selector').mouseOver(function(){
      // Callback code goes here.
    });
    ```
- `keyDown(callback)`:
  - This event handler is triggered when a key on the keyboard is pressed.
  - Syntax:
    ```javascript
    _œ('selector').keyDown(function(){
      // Callback code goes here.
    });
    ```
- `scroll(callback)`:
  - This event handler is triggered when the UI is scrolled.
  - Syntax:
    ```javascript
    _œ('selector').scroll(function(){
      // Callback code goes here.
    });
    ```
- `animationEnd(callback)`:
  - This event handler is triggered when a CSS animation ends.
  - Syntax:
    ```javascript
    _œ('selector').animationEnd(function(){
      // Callback code goes here.
    });
- `mouseOver(callback)`:
  - This event handler is triggered when a user moves their cursor over the selected object.
  - Syntax:
    ```javascript
    _œ('selector').mouseOver(function(){
      // Callback code goes here.
    });
    ```
- `mouseOut(callback)`:
  - This event handler is triggered when a user moves their cursor out of the selected object.
  - Syntax:
    ```javascript
    _œ('selector').mouseOut(function(){
      // Callback code goes here.
    });
    ```
